timespantools.offset_happens_when_timespan_stops
================================================

.. autofunction:: abjad.tools.timespantools.offset_happens_when_timespan_stops.offset_happens_when_timespan_stops
